pub fn retain_python_wrapper(component_id: ComponentId, wrapper: Py<PyAny>)Expand description
Retains the strong reference which keeps the Python wrapper for component_id alive.
pub fn retain_python_wrapper(component_id: ComponentId, wrapper: Py<PyAny>)Retains the strong reference which keeps the Python wrapper for component_id alive.